Objects 📦
============================
.. toctree::
   :maxdepth: 1

   objects.tournaments


NovaDataclass Reference
-------------------------------------------
.. automodule:: novauniverse.objects.nova_dataclass
   :members:
   :undoc-members:
   :show-inheritance:

NovaPlayer Reference
----------------------------------------
.. automodule:: novauniverse.objects.nova_player
   :members:
   :undoc-members:
   :show-inheritance:

OrderBy Reference
-------------------------------------
.. automodule:: novauniverse.objects.order_by
   :members:
   :undoc-members:
   :show-inheritance:

Timestamp Reference
-------------------------------------
.. automodule:: novauniverse.objects.timestamp
   :members:
   :undoc-members:
   :show-inheritance: